 /****************************************************************************
** File:    mail_utl_2.c
**
** Description: This module contains a function for sending mail using
**              the /bin/mailx mail program.
**
**      Author: Fred Polizo, Jr.    FP Systems
****************************************************************************/

#include <stdio.h>
#include <errno.h>

#include <oratypes.h>

/****************************************************************************
** Function:    send_mail
**
** Description: A function that sends a mail message to the specified
**              list of recipients (space or comma delimited).
**
**              Returns a value of 0 if no errors were reported by the OS.
**              Otherwise, it returns a OS error code.
****************************************************************************/
sb4 
send_mail (char *pReturnAddress,
           char *pRecipientList,
           char *pSubject,
           char *pMessage)
{
    sb4 errorStatus;
    char mailCmd[BUFSIZ];
    FILE *pMailPipe;

    /* Format the parameters into a mail command line */
    sprintf(mailCmd,
            "/bin/mailx -r '%s' -s '%s' %s",
            pReturnAddress,
            pSubject,
            pRecipientList);
    
    /* Reset the last system error value */
    errno = 0;
    
    /* open a pipe to the mail program */
    if ( (pMailPipe = popen (mailCmd, "w")) != NULL )
    {
        if ( fwrite (pMessage, strlen (pMessage), 1, pMailPipe)
             == strlen (pMessage) )
        {
            /* now close the pipe and return termination status */
            errorStatus = pclose(pMailPipe);
        }
        else
        {
            /* we couldn't write the message buffer, return the error */
            errorStatus = errno;
            (void) pclose (pMailPipe);
        }
    }
    else
    {
        /* we failed to open a pipe to the command, return the error */
        errorStatus = errno;
    }
    
    return errorStatus;
}
